@@ -115,8 +115,6 @@ public:
      */
     void reloadAccounts();
 
-    void queueNotifications();
-
     /**
      * @return If the currently selected account has issues with authentication.
      */
@@ -212,8 +210,6 @@ Q_SIGNALS:
 
     void identityChanged(AbstractAccount *account);
 
-    void finishedNotificationQueue();
-
 public Q_SLOTS:
 
     void childIdentityChanged(AbstractAccount *account);
