@@ -4,6 +4,9 @@
 #include "editor/listeditorbackend.h"
 
 #include <KLocalizedString>
+#include <QJsonDocument>
+#include <QNetworkReply>
+#include <QUrlQuery>
 
 #include "account/abstractaccount.h"
 #include "account/accountmanager.h"
@@ -36,8 +39,10 @@ void ListEditorBackend::setListId(const QString &listId)
     Q_EMIT loadingChanged();
 
     auto account = AccountManager::instance().selectedAccount();
+    m_favorite = account->isFavoriteList(m_listId);
+    Q_EMIT favoriteChanged();
 
-    account->get(account->apiUrl(QStringLiteral("/api/v1/lists/%1").arg(m_listId)), true, this, [=](QNetworkReply *reply) {
+    account->get(account->apiUrl(QStringLiteral("/api/v1/lists/%1").arg(m_listId)), true, this, [this](QNetworkReply *reply) {
         const auto document = QJsonDocument::fromJson(reply->readAll());
 
         m_title = document["title"_L1].toString();
@@ -83,11 +88,17 @@ void ListEditorBackend::submit()
 
     // If the listId is empty, then create a new list
     if (m_listId.isEmpty()) {
-        account->post(account->apiUrl(QStringLiteral("/api/v1/lists")), formdata, true, this, [=](QNetworkReply *) {
+        account->post(account->apiUrl(QStringLiteral("/api/v1/lists")), formdata, true, this, [this](QNetworkReply *) {
             Q_EMIT done();
         });
     } else {
-        account->put(account->apiUrl(QStringLiteral("/api/v1/lists/%1").arg(m_listId)), formdata, true, this, [=](QNetworkReply *) {
+        if (m_favorite) {
+            account->addFavoriteList(m_listId);
+        } else {
+            account->removeFavoriteList(m_listId);
+        }
+
+        account->put(account->apiUrl(QStringLiteral("/api/v1/lists/%1").arg(m_listId)), formdata, true, this, [this](QNetworkReply *) {
             Q_EMIT done();
         });
     }
@@ -99,7 +110,8 @@ void ListEditorBackend::deleteList()
 
     auto account = AccountManager::instance().selectedAccount();
 
-    account->deleteResource(account->apiUrl(QStringLiteral("/api/v1/lists/%1").arg(m_listId)), true, this, [=](QNetworkReply *) {
+    account->deleteResource(account->apiUrl(QStringLiteral("/api/v1/lists/%1").arg(m_listId)), true, this, [this, account](QNetworkReply *) {
+        account->removeFavoriteList(m_listId);
         Q_EMIT done();
     });
 }
