@@ -3,7 +3,8 @@
 
 #pragma once
 
-#include <QtQml>
+#include <QAbstractListModel>
+#include <QQmlEngine>
 
 struct Time {
     QString name;
@@ -28,4 +29,4 @@ public:
 
 private:
     QList<Time> m_times;
-};
\ No newline at end of file
+};
