@@ -4,8 +4,12 @@
 #include "search/searchmodel.h"
 
 #include "account/account.h"
+#include "networkcontroller.h"
 
 #include <KLocalizedString>
+#include <QJsonDocument>
+#include <QNetworkReply>
+#include <QUrlQuery>
 
 using namespace Qt::Literals::StringLiterals;
 
@@ -14,7 +18,7 @@ SearchModel::SearchModel(QObject *parent)
 {
     m_account = AccountManager::instance().selectedAccount();
 
-    connect(&AccountManager::instance(), &AccountManager::accountSelected, this, [=](AbstractAccount *account) {
+    connect(&AccountManager::instance(), &AccountManager::accountSelected, this, [this](AbstractAccount *account) {
         if (m_account != account) {
             m_account = account;
             beginResetModel();
@@ -47,37 +51,37 @@ void SearchModel::search(const QString &queryString, const QString &type, const
     url.setQuery(query);
     setLoading(true);
     setLoaded(false);
-    m_account->get(url, true, this, [this](QNetworkReply *reply) {
-        const auto searchResult = QJsonDocument::fromJson(reply->readAll()).object();
-        const auto statuses = searchResult[QStringLiteral("statuses")].toArray();
+    m_account->get(
+        url,
+        true,
+        this,
+        [this](QNetworkReply *reply) {
+            const auto searchResult = QJsonDocument::fromJson(reply->readAll()).object();
+            const auto statuses = searchResult[QStringLiteral("statuses")].toArray();
 
-        beginResetModel();
-        clear();
+            beginResetModel();
+            clear();
 
-        std::transform(
-            statuses.cbegin(),
-            statuses.cend(),
-            std::back_inserter(m_statuses),
-            [this](const QJsonValue &value) -> auto{ return new Post(m_account, value.toObject(), this); });
-        const auto accounts = searchResult[QStringLiteral("accounts")].toArray();
-        std::transform(
-            accounts.cbegin(),
-            accounts.cend(),
-            std::back_inserter(m_accounts),
-            [this](const QJsonValue &value) -> auto{
+            std::ranges::transform(std::as_const(statuses), std::back_inserter(m_statuses), [this](const QJsonValue &value) -> auto {
+                return new Post(m_account, value.toObject(), this);
+            });
+            const auto accounts = searchResult[QStringLiteral("accounts")].toArray();
+            std::ranges::transform(std::as_const(accounts), std::back_inserter(m_accounts), [this](const QJsonValue &value) -> auto {
                 const auto account = value.toObject();
                 return m_account->identityLookup(account["id"_L1].toString(), account);
             });
-        const auto hashtags = searchResult[QStringLiteral("hashtags")].toArray();
-        std::transform(
-            hashtags.cbegin(),
-            hashtags.cend(),
-            std::back_inserter(m_hashtags),
-            [](const QJsonValue &value) -> auto{ return SearchHashtag(value.toObject()); });
-        endResetModel();
-        setLoading(false);
-        setLoaded(true);
-    });
+            const auto hashtags = searchResult[QStringLiteral("hashtags")].toArray();
+            std::ranges::transform(std::as_const(hashtags), std::back_inserter(m_hashtags), [](const QJsonValue &value) -> auto {
+                return SearchHashtag(value.toObject());
+            });
+            endResetModel();
+            setLoading(false);
+            setLoaded(true);
+        },
+        [this](QNetworkReply *reply) {
+            setLoading(false);
+            Q_EMIT NetworkController::instance().networkErrorOccurred(reply->errorString());
+        });
 }
 
 int SearchModel::rowCount(const QModelIndex &parent) const
