@@ -96,10 +96,11 @@ class Post : public QObject
     Q_PROPERTY(QString language READ language CONSTANT)
     Q_PROPERTY(QString inReplyTo READ inReplyTo CONSTANT)
     Q_PROPERTY(QStringList mentions READ mentions CONSTANT)
-    Q_PROPERTY(Poll *poll READ poll NOTIFY pollChanged)
+    Q_PROPERTY(Poll poll READ poll NOTIFY pollChanged)
+    Q_PROPERTY(bool hasPoll READ hasPoll NOTIFY pollChanged)
     Q_PROPERTY(QStringList filters READ filters CONSTANT)
     Q_PROPERTY(Identity *authorIdentity READ getAuthorIdentity CONSTANT)
-    Q_PROPERTY(QQmlListProperty<Attachment> attachments READ attachmentList CONSTANT)
+    Q_PROPERTY(QList<Attachment *> attachments READ attachments CONSTANT)
     Q_PROPERTY(QString relativeTime READ relativeTime CONSTANT)
     Q_PROPERTY(QString absoluteTime READ absoluteTime CONSTANT)
     Q_PROPERTY(Card *card READ getCard CONSTANT)
@@ -379,10 +380,10 @@ private:
 
     [[nodiscard]] Identity *getAuthorIdentity() const;
 
-    [[nodiscard]] QQmlListProperty<Attachment> attachmentList() const;
-
     [[nodiscard]] Card *getCard() const;
 
+    [[nodiscard]] bool hasPoll() const;
+
     void setCard(std::optional<Card> card);
 
     void setApplication(std::optional<Application> application);
@@ -413,7 +414,6 @@ private:
     std::optional<Application> m_application;
     std::shared_ptr<Identity> m_authorIdentity;
     QList<Attachment *> m_attachments;
-    QQmlListProperty<Attachment> m_attachmentList;
     std::unique_ptr<Poll> m_poll;
 
     bool m_sensitive = false;
