@@ -1,9 +1,9 @@
 // SPDX-FileCopyrightText: None
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
-#include "emojitones.h"
+#include "utils/emojitones.h"
 #include "utils/emojimodel.h"
 
 QMultiHash<QString, QVariant> EmojiTones::_tones = {
-#include "emojitones_data.h"
+#include "utils/emojitones_data.h"
 };
